<?php
namespace MikadoCore\Lib;

use MikadoCore\CPT\Portfolio;
use MikadoCore\CPT\Carousels;
use MikadoCore\CPT\Slider;
use MikadoCore\CPT\Testimonials;
use MikadoCore\CPT\Doctors;

/**
 * Class ShortcodeLoader
 * @package MikadoCore\Lib
 */
class ShortcodeLoader {
	/**
	 * @var private instance of current class
	 */
	private static $instance;
	/**
	 * @var array
	 */
	private $loadedShortcodes = array();

	/**
	 * Private constuct because of Singletone
	 */
	private function __construct() {
	}

	/**
	 * Returns current instance of class
	 * @return ShortcodeLoader
	 */
	public static function getInstance() {
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof self ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Adds new shortcode. Object that it takes must implement ShortcodeInterface
	 *
	 * @param ShortcodeInterface $shortcode
	 */
	private function addShortcode(ShortcodeInterface $shortcode) {
		if(!array_key_exists($shortcode->getBase(), $this->loadedShortcodes)) {
			$this->loadedShortcodes[$shortcode->getBase()] = $shortcode;
		}
	}

	/**
	 * Adds all shortcodes.
	 *
	 * @see ShortcodeLoader::addShortcode()
	 */
	private function addShortcodes() {
		$this->addShortcode(new Portfolio\Shortcodes\PortfolioList());
		$this->addShortcode(new Portfolio\Shortcodes\PortfolioSlider());
		$this->addShortcode(new Portfolio\Shortcodes\PortfolioMarquee());
		$this->addShortcode(new Carousels\Shortcodes\Carousel());
		$this->addShortcode(new Slider\Shortcodes\Slider());
		$this->addShortcode(new Testimonials\Shortcodes\Testimonials());
		$this->addShortcode(new Doctors\Shortcodes\BookingForm());
	}

	/**
	 * Calls ShortcodeLoader::addShortcodes and than loops through added shortcodes and calls render method
	 * of each shortcode object
	 */
	public function load() {
		$this->addShortcodes();

		foreach($this->loadedShortcodes as $shortcode) {
			add_shortcode($shortcode->getBase(), array($shortcode, 'render'));
		}

	}
}
