<?php
namespace MikadoCore\CPT;

use MikadoCore\Lib;

/**
 * Class PostTypesLoader
 * @package MikadoCore\CPT
 */
class PostTypesRegister {
	/**
	 * @var private instance of the class
	 */
	private static $instance;
	/**
	 * @var array
	 */
	private $postTypes = array();

	/**
	 * Private construct because of Singletone
	 */
	private function __construct() {
	}

	/**
	 * Returns current instance of class
	 * @return PostTypesRegister
	 */
	public static function getInstance() {
		if ( ! isset( self::$instance ) && ! ( self::$instance instanceof self ) ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	/**
	 * Adds post type to post types array
	 *
	 * @param Lib\PostTypeInterface $postType
	 */
	private function addPostType(Lib\PostTypeInterface $postType) {
		if(!array_key_exists($postType->getBase(), $this->postTypes)) {
			$this->postTypes[$postType->getbase()] = $postType;
		}
	}

	/**
	 * Returns post type object by it's slug
	 *
	 * @param $slug
	 *
	 * @return mixed
	 */
	public function getPostType($slug) {
		if(array_key_exists($slug, $this->postTypes)) {
			return $this->postTypes[$slug];
		}
	}

	/**
	 * Adds all post types
	 *
	 * @see PostTypesLoader::addPostType()
	 */
	private function addPostTypes() {
		$this->addPostType(new Portfolio\PortfolioRegister());
		$this->addPostType(new Testimonials\TestimonialsRegister());
		$this->addPostType(new Carousels\CarouselRegister());
		$this->addPostType(new Slider\SliderRegister());
		$this->addPostType(new Doctors\DoctorsRegister());
	}

	/**
	 * Calss addPostTypes method, loops through each post type in array and calls register method
	 */
	public function register() {
		$this->addPostTypes();

		foreach($this->postTypes as $postType) {
			$postType->register();
		}

	}
}
