<?php
namespace Medigroup\Modules\InfoList;

use Medigroup\Modules\Shortcodes\Lib\ShortcodeInterface;

/**
 * class Accordions
 */
class InfoList implements ShortcodeInterface {
	/**
	 * @var string
	 */
	private $base;

	function __construct() {
		$this->base = 'mkd_info_list';
		add_action('vc_before_init', array($this, 'vcMap'));
	}

	public function getBase() {
		return $this->base;
	}

	public function vcMap() {

		vc_map(array(
			'name'                    => esc_html__('Info List', 'mikado-core'),
			'base'                    => $this->base,
			'as_parent'               => array('only' => 'mkd_info_list_item'),
			'content_element'         => true,
			'category'                => esc_html__('by MIKADO', 'mikado-core'),
			'icon'                    => 'icon-wpb-info-list extended-custom-icon',
			'show_settings_on_create' => true,
			'js_view'                 => 'VcColumnView',
			'params'                  => array(
				array(
					'type'        => 'textfield',
					'heading'     => esc_html__('Title', 'mikado-core'),
					'param_name'  => 'title',
					'admin_label' => true,
					'value'       => ''
				),
				array(
					'type'        => 'textfield',
					'heading'     => esc_html__('Button Text', 'mikado-core'),
					'param_name'  => 'link_text',
					'admin_label' => true,
					'description' => esc_html__('Enter text for the button below the list items.', 'mikado-core')
				),
				array(
					'type'        => 'textfield',
					'heading'     => esc_html__('Button Link', 'mikado-core'),
					'param_name'  => 'link',
					'admin_label' => true,
					'dependency'  => array('element' => 'link_text', 'not_empty' => true)
				),
				array(
					'type'        => 'dropdown',
					'heading'     => esc_html__('Button Target', 'mikado-core'),
					'param_name'  => 'target',
					'value'       => array(
						esc_html__('Self', 'mikado-core')  => '_self',
						esc_html__('Blank', 'mikado-core') => '_blank'
					),
					'save_always' => true,
					'admin_label' => true,
					'dependency'  => array('element' => 'link_text', 'not_empty' => true)
				)
			)
		));
	}

	public function render($atts, $content = null) {
		$default_atts = array(
			'title' => '',
			'link_text' => '',
			'link' => '',
			'target' => ''
		);

		$params       = shortcode_atts($default_atts, $atts);
		extract($params);

		$params['content']   = $content;

		$output = '';

		$output .= mkd_core_get_core_shortcode_template_part('templates/info-list-template', 'info-list', '', $params);

		return $output;
	}
}
