<?php
namespace Medigroup\Modules\Shortcodes\WorkingHours;

use Medigroup\Modules\Shortcodes\Lib\ShortcodeInterface;

class WorkingHours implements ShortcodeInterface {
    private $base;

    public function __construct() {
        $this->base = 'mkd_working_hours';

        add_action('vc_before_init', array($this, 'vcMap'));
    }

    public function getBase() {
        return $this->base;
    }

    public function vcMap() {
        vc_map(array(
            'name'                      => esc_html__('Mikado Working Hours', 'mikado-core'),
            'base'                      => $this->base,
            'category'                  => esc_html__('by MIKADO', 'mikado-core'),
            'icon'                      => 'icon-wpb-working-hours extended-custom-icon',
            'allowed_container_element' => 'vc_row',
            'params'                    => array_merge(
                medigroup_mikado_icon_collections()->getVCParamsArray(array(), '', true),
                array(
                    array(
                        'type'        => 'colorpicker',
                        'admin_label' => true,
                        'heading'     => esc_html__('Background Color', 'mikado-core'),
                        'param_name'  => 'bckg_color',
                        'description' => ''
                    ),
                    array(
                        'type'        => 'colorpicker',
                        'admin_label' => true,
                        'heading'     => esc_html__('Text Color', 'mikado-core'),
                        'param_name'  => 'text_color',
                        'description' => ''
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Title', 'mikado-core'),
                        'param_name'  => 'title',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true
                    ),
                    array(
                        'type'        => 'textfield',
                        'admin_label' => true,
                        'heading'     => esc_html__('Custom Size (px) for Title', 'mikado-core'),
                        'param_name'  => 'custom_size_title',
                        'value'       => ''
                    ),
                    array(
                        'type'        => 'dropdown',
                        'heading'     => esc_html__('Font Weight for Title', 'mikado-core'),
                        'param_name'  => 'font_weight_title',
                        'value'       => array_flip(medigroup_mikado_get_font_weight_array(true)),
                        'admin_label' => true,
                        'save_always' => true
                    ),
                    array(
                        'type'        => 'dropdown',
                        'heading'     => esc_html__('Text Transform for Title', 'mikado-core'),
                        'param_name'  => 'text_transform_title',
                        'value'       => array_flip(medigroup_mikado_get_text_transform_array(true)),
                        'admin_label' => true,
                        'save_always' => true
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Text', 'mikado-core'),
                        'param_name'  => 'text',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true
                    ),
                    array(
                        'type'        => 'textfield',
                        'admin_label' => true,
                        'heading'     => esc_html__('Custom Size (px) for Text', 'mikado-core'),
                        'param_name'  => 'custom_size_text',
                        'value'       => ''
                    ),
                    array(
                        'type'        => 'textfield',
                        'admin_label' => true,
                        'heading'     => esc_html__('Custom Size (px) for Day and Time', 'mikado-core'),
                        'param_name'  => 'custom_size_day',
                        'value'       => ''
                    ),
                    array(
                        'type'        => 'dropdown',
                        'heading'     => esc_html__('Show Button?', 'mikado-core'),
                        'param_name'  => 'wh_button',
                        'admin_label' => true,
                        'value'       => array(
                            esc_html__('Yes', 'mikado-core') => 'yes',
                            esc_html__('No', 'mikado-core')  => 'no'
                        ),
                        'save_always' => true
                    ),
                    array(
                        'type'        => 'dropdown',
                        'heading'     => esc_html__('Format', 'mikado-core'),
                        'param_name'  => 'format',
                        'admin_label' => true,
                        'value'       => array(
                            esc_html__('Work Days + Weekend', 'mikado-core')                     => '5_2',
                            esc_html__('Work Days + Saturday + Sunday', 'mikado-core')           => '5_1_1',
                            esc_html__('Same Throught the Week', 'mikado-core')                  => '7',
                            esc_html__('Mon + Tue + Wed + Thu + Fri + Weekend', 'mikado-core')   => '1_1_1_1_1_2',
                            esc_html__('Mon + Tue + Wed + Thu + Fri + Sat + Sun', 'mikado-core') => '1_1_1_1_1_1_1',
                        ),
                        'save_always' => true
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Monday To Sunday', 'mikado-core'),
                        'param_name'  => 'monday_to_sunday',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true,
                        'group'       => esc_html__('Settings', 'mikado-core'),
                        'dependency'  => array('element' => 'format', 'value' => array('7'))
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Monday To Friday', 'mikado-core'),
                        'param_name'  => 'monday_to_friday',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true,
                        'group'       => esc_html__('Settings', 'mikado-core'),
                        'dependency'  => array('element' => 'format', 'value' => array('5_2', '5_1_1'))
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Weekend', 'mikado-core'),
                        'param_name'  => 'weekend',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true,
                        'group'       => esc_html__('Settings', 'mikado-core'),
                        'dependency'  => array('element' => 'format', 'value' => array('5_2', '1_1_1_1_1_2'))
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Monday', 'mikado-core'),
                        'param_name'  => 'monday',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true,
                        'group'       => esc_html__('Settings', 'mikado-core'),
                        'dependency'  => array('element' => 'format', 'value' => array('1_1_1_1_1_2', '1_1_1_1_1_1_1'))
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Tuesday', 'mikado-core'),
                        'param_name'  => 'tuesday',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true,
                        'group'       => esc_html__('Settings', 'mikado-core'),
                        'dependency'  => array('element' => 'format', 'value' => array('1_1_1_1_1_2', '1_1_1_1_1_1_1'))
                    ),
                    array(
                        'type'        => 'textfield',
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Wednesday', 'mikado-core'),
                        'param_name'  => 'wednesday',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true,
                        'group'       => esc_html__('Settings', 'mikado-core'),
                        'dependency'  => array('element' => 'format', 'value' => array('1_1_1_1_1_2', '1_1_1_1_1_1_1'))
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Thursday', 'mikado-core'),
                        'param_name'  => 'thursday',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true,
                        'group'       => esc_html__('Settings', 'mikado-core'),
                        'dependency'  => array('element' => 'format', 'value' => array('1_1_1_1_1_2', '1_1_1_1_1_1_1'))
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Friday', 'mikado-core'),
                        'param_name'  => 'friday',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true,
                        'group'       => esc_html__('Settings', 'mikado-core'),
                        'dependency'  => array('element' => 'format', 'value' => array('1_1_1_1_1_2', '1_1_1_1_1_1_1'))
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Saturday', 'mikado-core'),
                        'param_name'  => 'saturday',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true,
                        'group'       => esc_html__('Settings', 'mikado-core'),
                        'dependency'  => array('element' => 'format', 'value' => array('5_1_1', '1_1_1_1_1_1_1'))
                    ),
                    array(
                        'type'        => 'textfield',
                        'heading'     => esc_html__('Sunday', 'mikado-core'),
                        'param_name'  => 'sunday',
                        'admin_label' => true,
                        'value'       => '',
                        'save_always' => true,
                        'group'       => esc_html__('Settings', 'mikado-core'),
                        'dependency'  => array('element' => 'format', 'value' => array('5_1_1', '1_1_1_1_1_1_1'))
                    )
                )
            )
        ));
    }

    public function render($atts, $content = null) {
        $default_atts = array(
            'bckg_color'           => '',
            'text_color'           => '',
            'title'                => '',
            'custom_size_title'    => '',
            'font_weight_title'    => '',
            'text_transform_title' => '',
            'text'                 => '',
            'custom_size_text'     => '',
            'custom_size_day'      => '',
            'wh_button'            => '',
            'format'               => '',
            'monday_to_friday'     => '',
            'weekend'              => '',
            'monday'               => '',
            'tuesday'              => '',
            'wednesday'            => '',
            'thursday'             => '',
            'friday'               => '',
            'saturday'             => '',
            'sunday'               => '',
            'monday_to_sunday'     => ''
        );

        $default_atts = array_merge($default_atts, medigroup_mikado_icon_collections()->getShortcodeParams());
        $params       = shortcode_atts($default_atts, $atts);

        $iconPackName   = medigroup_mikado_icon_collections()->getIconCollectionParamNameByKey($params['icon_pack']);
        $params['icon'] = $iconPackName ? $params[$iconPackName] : '';

        $params['working_hours'] = $this->getWorkingHours($params);
        $params['wh_colors']     = $this->getBckgStyles($params);
        $params['bckg_color']    = $this->getIconStyles($params);
        $params['title_color']   = $this->getTitleStyles($params);
        $params['text_size']     = $this->getTextStyles($params);
        $params['date_size']     = $this->getDayStyles($params);
        $params['show_icon']     = !empty($params['icon']);

        return mkd_core_get_core_shortcode_template_part('templates/working-hours-template', 'working-hours', '', $params);
    }

    private function getWorkingHours($params) {
        $workingHours = array();

        if(!empty($params['format']) && $params['format'] === '5_2') {
            if(!empty($params['monday_to_friday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Monday - Friday', 'mikado-core'),
                    'time'  => $params['monday_to_friday']
                );
            }

            if(!empty($params['weekend'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Saturday - Sunday', 'mikado-core'),
                    'time'  => $params['weekend']
                );
            }
        } else if(!empty($params['format']) && $params['format'] === '1_1_1_1_1_1_1') {
            if(!empty($params['monday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Monday', 'mikado-core'),
                    'time'  => $params['monday']
                );
            }

            if(!empty($params['tuesday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Tuesday', 'mikado-core'),
                    'time'  => $params['tuesday']
                );
            }

            if(!empty($params['wednesday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Wednesday', 'mikado-core'),
                    'time'  => $params['wednesday']
                );
            }

            if(!empty($params['thursday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Thursday', 'mikado-core'),
                    'time'  => $params['thursday']
                );
            }

            if(!empty($params['friday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Friday', 'mikado-core'),
                    'time'  => $params['friday']
                );
            }

            if(!empty($params['saturday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Saturday', 'mikado-core'),
                    'time'  => $params['saturday']
                );
            }

            if(!empty($params['sunday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Sunday', 'mikado-core'),
                    'time'  => $params['sunday']
                );
            }
        } else if(!empty($params['format']) && $params['format'] === '1_1_1_1_1_2') {
            if(!empty($params['monday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Monday', 'mikado-core'),
                    'time'  => $params['monday']
                );
            }

            if(!empty($params['tuesday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Tuesday', 'mikado-core'),
                    'time'  => $params['tuesday']
                );
            }

            if(!empty($params['wednesday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Wednesday', 'mikado-core'),
                    'time'  => $params['wednesday']
                );
            }

            if(!empty($params['thursday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Thursday', 'mikado-core'),
                    'time'  => $params['thursday']
                );
            }

            if(!empty($params['friday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Friday', 'mikado-core'),
                    'time'  => $params['friday']
                );
            }

            if(!empty($params['weekend'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Saturday - Sunday', 'mikado-core'),
                    'time'  => $params['weekend']
                );
            }
        } else if(!empty($params['format']) && $params['format'] === '5_1_1') {
            if(!empty($params['monday_to_friday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Monday - Friday', 'mikado-core'),
                    'time'  => $params['monday_to_friday']
                );
            }

            if(!empty($params['saturday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Saturday', 'mikado-core'),
                    'time'  => $params['saturday']
                );
            }

            if(!empty($params['sunday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Sunday', 'mikado-core'),
                    'time'  => $params['sunday']
                );
            }
        } else if(!empty($params['format']) && $params['format'] === '7') {
            if(!empty($params['monday_to_sunday'])) {
                $workingHours[] = array(
                    'label' => esc_html__('Monday - Sunday', 'mikado-core'),
                    'time'  => $params['monday_to_sunday']
                );
            }
        }

        return $workingHours;
    }

    private function getBckgStyles($params) {
        $styles = array();

        if($params['bckg_color'] !== '') {
            $styles[] = 'background-color: '.$params['bckg_color'];
        }

        if($params['text_color'] !== '') {
            $styles[] = 'color: '.$params['text_color'];
        }

        return $styles;
    }

    private function getIconStyles($params) {
        $styles = array();

        if($params['bckg_color'] !== '') {
            $styles[] = 'background-color: '.$params['bckg_color'];
        }

        return $styles;
    }

    private function getTitleStyles($params) {
        $styles = array();

        if($params['text_color'] !== '') {
            $styles[] = 'color: '.$params['text_color'];
        }

        if(!empty($params['custom_size_title'])) {
            $styles[] = 'font-size:'.medigroup_mikado_filter_px($params['custom_size_title']).'px';
        }

        if(!empty($params['font_weight_title'])) {
            $styles[] = 'font-weight: '.$params['font_weight_title'];
        }

        if(!empty($params['text_transform_title'])) {
            $styles[] = 'text-transform: '.$params['text_transform_title'];
        }

        return $styles;
    }

    private function getTextStyles($params) {
        $styles = array();

        if(!empty($params['custom_size_text'])) {
            $styles[] = 'font-size:'.medigroup_mikado_filter_px($params['custom_size_text']).'px';
        }

        return $styles;
    }

    private function getDayStyles($params) {
        $styles = array();

        if(!empty($params['custom_size_day'])) {
            $styles[] = 'font-size:'.medigroup_mikado_filter_px($params['custom_size_day']).'px';
        }

        return $styles;
    }
}
